const logger = require('@firstfleet/fflogger');
const slack = require('@firstfleet/ffslack');

/**
 * DEPRECATED! Still works but please use logAndNotify 
 * Currently setup to proxy calls to logAndNotify. 
 *
 * IF YOU SEE THIS METHOD BEING USED, PLEASE REPALCE IT
 * @param {string} sender - Machine sending the error
 * @param {string} method - method sending the error
 * @param {string} message - error description
 * @param {string} severity - which errorLevel (defined in error handler)
 * @param {boolean} isOperational - is it an operational error or programmer error
 * @param {string} channelId - slack channel to post to if error is critical
 * @param {boolean} sendToSlack - should the message be sent to slack, even if not critical
 * @deprecated
 * @returns {void}
 */
const handleError = (sender, method, message, severity, isOperational, channelId = 'alerts_critical', sendToSlack = false) => {
    if (sendToSlack) {
        module.exports.logAndNotify(sender, method, message, "", channelId);
    } else {
        module.exports.logAndNotify(sender, method, message, "");
    }
};

/**
 * Logs error message to papertrail and optionally posts to Slack
 * @param {string} appName - Name of the application (ex: NodeJobsConsumer)
 * @param {string} methodName - Name of method (ex: AuditCard)
 * @param {string} message - Error message (just the error, no distinct details)
 * @param {string} messageDetail - Details or stack trace of the error (ex: DriverID - BEAB)
 * @param {string} [slackChannel] - If Slack post desired, this channel will be used
 */
const logAndNotify = (appName, methodName, message, messageDetail, slackChannel) => {
    try {
        /** 
         * If AppName is missing, use the env PAPERTRAIL_PROGRAM as the app name
         * if it is available
         * */
        if (!appName && process?.env?.PAPERTRAIL_PROGRAM) {
            appName = process.env.PAPERTRAIL_PROGRAM;
        }

        logger.error(appName, methodName, `Error: ${message}\n${messageDetail}`, '');
        if (slackChannel) {
            slack.PostToSlack(appName, `${methodName}-${message}`, slackChannel, messageDetail);
        }
    } catch (error) {
        console.error(error);
    }
};

/** 
 * Proxied to logAndNotify, DO NOT USE
 *
 * If you see this call being used in the code you are working on, please update to call
 * logAndNotify instead.
 * @deprecated
 * */
function PostToSlack(appName, errorMessage, slackChannel, errorDetail) {
    module.exports.logAndNotify(appName, "", errorMessage, errorDetail, slackChannel);
}

module.exports = {
    handleError,
    logAndNotify,
    PostToSlack
}
